@@ -133,7 +133,10 @@ QRectF Geometry::rectAdjustedVisually(const QRectF &rect, qreal xp1, qreal yp1,
 
 QRectF Geometry::rectScaled(const QRectF &rect, qreal scale)
 {
-    return {rect.topLeft() * scale, rect.size() *scale};
+    if (scale == 1) {
+        return rect;
+    }
+    return {rect.topLeft() * scale, rect.size() * scale};
 }
 
 QRectF Geometry::rectIntersected(const QRectF &rect1, const QRectF &rect2)
@@ -166,6 +169,12 @@ QRectF Geometry::rectBounded(const QRectF &rect, const QRectF &boundsRect,
     return newRect;
 }
 
+QRectF Geometry::rectBounded(qreal x, qreal y, qreal width, qreal height, const QRectF &boundsRect,
+                             Qt::Orientations orientations)
+{
+    return rectBounded({x, y, width, height}, boundsRect, orientations);
+}
+
 QRectF Geometry::rectClipped(const QRectF &rect, const QRectF &clipRect,
                              Qt::Orientations orientations)
 {
