@@ -5,7 +5,6 @@
  */
 
 #include "ImagePlatformXcb.h"
-#include "ImageMetaData.h"
 
 #include <xcb/randr.h>
 #include <xcb/xcb_cursor.h>
@@ -92,17 +91,14 @@ public:
                 // decide whether to grab or abort. regrab the mouse on mouse-wheel events
                 {
                     auto secondEvent = static_cast<xcb_button_release_event_t *>(message);
-                    const xcb_button_t button = secondEvent->detail;
-                    if (button == XCB_BUTTON_INDEX_1) {
+                    if (secondEvent->detail == 1) {
                         QTimer::singleShot(0, nullptr, [this]() {
                             m_platformPtr->doGrabNow(m_grabMode, m_includePointer, m_includeDecorations, m_includeShadow);
                         });
-                    } else if (button == XCB_BUTTON_INDEX_2 || button == XCB_BUTTON_INDEX_3) {
+                    } else if (secondEvent->detail == 2 || secondEvent->detail == 3) {
                         // 2: middle click, 3: right click; both cancel
                         Q_EMIT m_platformPtr->newScreenshotTaken();
-                    } else if (button < XCB_BUTTON_INDEX_4) {
-                        // This code makes no sense, but it's replicating the original behavior
-                        // with more descriptive code.
+                    } else if (secondEvent->detail < 4) {
                         Q_EMIT m_platformPtr->newScreenshotFailed();
                     } else {
                         QTimer::singleShot(0, nullptr, [this]() {
@@ -184,6 +180,24 @@ void ImagePlatformXcb::doGrab(ShutterMode shutterMode, GrabMode grabMode, bool i
     }
 }
 
+/* -- Platform Utilities ----------------------------------------------------------------------- */
+
+void ImagePlatformXcb::updateWindowTitle(xcb_window_t window)
+{
+    auto title = KX11Extras::readNameProperty(window, XA_WM_NAME);
+    Q_EMIT windowTitleChanged(title);
+}
+
+bool ImagePlatformXcb::isKWinAvailable()
+{
+    if (QDBusConnection::sessionBus().interface()->isServiceRegistered(u"org.kde.KWin"_s)) {
+        QDBusInterface iface(u"org.kde.KWin"_s, u"/Effects"_s, u"org.kde.kwin.Effects"_s);
+        QDBusReply<bool> reply = iface.call(u"isEffectLoaded"_s, u"screenshot"_s);
+        return reply.value();
+    }
+    return false;
+}
+
 /* -- XCB Utilities ---------------------------------------------------------------------------- */
 
 QPoint ImagePlatformXcb::getCursorPosition()
@@ -450,11 +464,6 @@ QImage ImagePlatformXcb::getToplevelImage(QRect rect, bool blendPointer)
     return postProcessImage(image, rect, blendPointer);
 }
 
-void setWindowTitle(QImage &image, xcb_window_t window)
-{
-    ImageMetaData::setWindowTitle(image, KX11Extras::readNameProperty(window, XA_WM_NAME));
-}
-
 QImage ImagePlatformXcb::getWindowImage(xcb_window_t window, bool blendPointer)
 {
     auto xcbConn = QX11Info::connection();
@@ -466,7 +475,6 @@ QImage ImagePlatformXcb::getWindowImage(xcb_window_t window, bool blendPointer)
 
     // then proceed to get an image
     auto image = getImageFromDrawable(window, windowRect);
-    setWindowTitle(image, window);
 
     // translate window coordinates to global ones.
     auto rootGeoCookie = xcb_get_geometry_unchecked(xcbConn, geoReply->root);
@@ -480,13 +488,33 @@ QImage ImagePlatformXcb::getWindowImage(xcb_window_t window, bool blendPointer)
 
     // if the window capture failed, try to obtain one from the full screen.
     if (image.isNull()) {
-        image = getToplevelImage(windowRect, blendPointer);
-        setWindowTitle(image, window);
-        return image;
+        return getToplevelImage(windowRect, blendPointer);
     }
     return postProcessImage(image, windowRect, blendPointer);
 }
 
+void ImagePlatformXcb::handleKWinScreenshotReply(quint64 drawable)
+{
+    QDBusConnection::sessionBus().disconnect(u"org.kde.KWin"_s,
+                                             u"/Screenshot"_s,
+                                             u"org.kde.kwin.Screenshot"_s,
+                                             u"screenshotCreated"_s,
+                                             this,
+                                             SLOT(handleKWinScreenshotReply(quint64)));
+
+    // obtain width and height and grab an image (x and y are always zero for drawables)
+    auto xcbDrawable = static_cast<xcb_drawable_t>(drawable);
+    auto rect = getDrawableGeometry(xcbDrawable);
+    auto image = getImageFromDrawable(xcbDrawable, rect);
+
+    if (!image.isNull()) {
+        image.setDevicePixelRatio(qGuiApp->devicePixelRatio());
+        Q_EMIT newScreenshotTaken(image);
+        return;
+    }
+    Q_EMIT newScreenshotFailed();
+}
+
 /* -- Grabber Methods -------------------------------------------------------------------------- */
 
 void ImagePlatformXcb::grabAllScreens(bool includePointer, bool crop)
@@ -550,7 +578,6 @@ void ImagePlatformXcb::grabApplicationWindow(xcb_window_t window, bool includePo
     if (windowInfo.valid()) {
         auto frameGeom = windowInfo.frameGeometry();
         image = getToplevelImage(frameGeom, includePointer);
-        setWindowTitle(image, window);
     }
 
     // fallback is window without the frame
@@ -559,17 +586,72 @@ void ImagePlatformXcb::grabApplicationWindow(xcb_window_t window, bool includePo
 
 void ImagePlatformXcb::grabActiveWindow(bool includePointer, bool includeDecorations, bool includeShadow)
 {
-    grabApplicationWindow(KX11Extras::activeWindow(), includePointer, includeDecorations);
+    auto activeWindow = KX11Extras::activeWindow();
+    updateWindowTitle(activeWindow);
+
+    // if KWin is available, use the KWin DBus interfaces
+    if (includeDecorations && isKWinAvailable()) {
+        auto bus = QDBusConnection::sessionBus();
+        bus.connect(u"org.kde.KWin"_s,
+                     u"/Screenshot"_s,
+                     u"org.kde.kwin.Screenshot"_s,
+                     u"screenshotCreated"_s,
+                     this,
+                     SLOT(handleKWinScreenshotReply(quint64)));
+        QDBusInterface iface(u"org.kde.KWin"_s, u"/Screenshot"_s, u"org.kde.kwin.Screenshot"_s);
+
+        int opMask = 1;
+        if (includePointer) {
+            opMask |= 1 << 1;
+        }
+        if (includeShadow) {
+            opMask |= 1 << 2;
+        }
+        iface.call(QStringLiteral("screenshotForWindow"), static_cast<quint64>(activeWindow), opMask);
+
+        return;
+    }
+
+    // otherwise, use the native functionality
+    grabApplicationWindow(activeWindow, includePointer, includeDecorations);
 }
 
 void ImagePlatformXcb::grabWindowUnderCursor(bool includePointer, bool includeDecorations, bool includeShadow)
 {
-    grabApplicationWindow(getWindowUnderCursor(), includePointer, includeDecorations);
+    auto window = getWindowUnderCursor();
+    updateWindowTitle(window);
+
+    // if KWin is available, use the KWin DBus interfaces
+    if (includeDecorations && isKWinAvailable()) {
+        auto bus = QDBusConnection::sessionBus();
+        bus.connect(u"org.kde.KWin"_s,
+                     u"/Screenshot"_s,
+                     u"org.kde.kwin.Screenshot"_s,
+                     u"screenshotCreated"_s,
+                     this,
+                     SLOT(handleKWinScreenshotReply(quint64)));
+        QDBusInterface interface(u"org.kde.KWin"_s, u"/Screenshot"_s, u"org.kde.kwin.Screenshot"_s);
+
+        int opMask = 1;
+        if (includePointer) {
+            opMask |= 1 << 1;
+        }
+        if (includeShadow) {
+            opMask |= 1 << 2;
+        }
+        interface.call(u"screenshotWindowUnderCursor"_s, opMask);
+
+        return;
+    }
+
+    // otherwise, use the native functionality
+    grabApplicationWindow(window, includePointer, includeDecorations);
 }
 
 void ImagePlatformXcb::grabTransientWithParent(bool includePointer, bool includeDecorations, bool includeShadow)
 {
     auto window = getWindowUnderCursor();
+    updateWindowTitle(window);
 
     // grab the image early
     auto image = getToplevelImage(QRect(), false);
@@ -601,7 +683,7 @@ void ImagePlatformXcb::grabTransientWithParent(bool includePointer, bool include
     // All parents are known now, find other transient children.
     // Assume that the lowest window is behind everything else, then if a new
     // transient window is discovered, its children can then also be found.
-    const auto winList = KX11Extras::stackingOrder();
+    auto winList = KX11Extras::stackingOrder();
     for (auto winId : winList) {
         QRect winRect;
         auto parentWindow = getTransientWindowParent(winId, winRect, includeDecorations);
@@ -640,6 +722,10 @@ void ImagePlatformXcb::grabTransientWithParent(bool includePointer, bool include
 
 void ImagePlatformXcb::doGrabNow(GrabMode grabMode, bool includePointer, bool includeDecorations, bool includeShadow)
 {
+    if (grabMode & ~(ActiveWindow | WindowUnderCursor | TransientWithParent)) {
+        // Notify that window title is empty since we are not picking a window.
+        Q_EMIT windowTitleChanged();
+    }
     switch (grabMode) {
     case GrabMode::AllScreens:
     case GrabMode::AllScreensScaled:
