@@ -129,7 +129,9 @@ void VideoPlatformWayland::startRecording(const QUrl &fileUrl, RecordingMode rec
         return;
     }
 
-    Screencasting::CursorMode mode = includePointer ? Screencasting::CursorMode::Metadata : Screencasting::Hidden;
+    // BUG: https://bugs.kde.org/show_bug.cgi?id=476964
+    // CursorMode::Metadata doesn't work.
+    Screencasting::CursorMode mode = includePointer ? Screencasting::CursorMode::Embedded : Screencasting::Hidden;
     ScreencastingStream *stream = nullptr;
     switch (recordingMode) {
     case Screen: {
@@ -177,9 +179,14 @@ void VideoPlatformWayland::startRecording(const QUrl &fileUrl, RecordingMode rec
             selectAndRecord(fileUrl, recordingMode, includePointer);
             return;
         }
-        // minimizeIfWindowsIntersect(region);
-        // Should this always be 1? Trying to match the screen(s) DPR resulted in a black video.
         qreal scaling = 1;
+        const auto screens = qGuiApp->screens();
+        // Don't make the resolution larger than it needs to be.
+        for (auto screen : screens) {
+            if (screen->geometry().intersects(region)) {
+                scaling = std::max(scaling, screen->devicePixelRatio());
+            }
+        }
         stream = m_screencasting->createRegionStream(region, scaling, mode);
         break;
     }
