@@ -24,13 +24,18 @@ public:
     VideoPlatformWayland(QObject *parent = nullptr);
 
     RecordingModes supportedRecordingModes() const override;
-    void startRecording(const QString &path, RecordingMode recordingMode, const RecordingOption &option, bool includePointer) override;
+    Formats supportedFormats() const override;
+    void startRecording(const QUrl &fileUrl, RecordingMode recordingMode, const QVariant &option, bool includePointer) override;
     void finishRecording() override;
-    QString extension() const override;
-    QStringList suggestedExtensions() const override;
-    void setExtension(const QString &encoder) override;
+
+    Format formatForEncoder(PipeWireBaseEncodedStream::Encoder encoder) const;
+    PipeWireBaseEncodedStream::Encoder encoderForFormat(Format format) const;
 
 private:
+    bool mkDirPath(const QUrl &fileUrl);
+    void setupOutput(const QUrl &fileUrl);
+    void selectAndRecord(const QUrl &fileUrl, RecordingMode recordingMode, bool includePointer);
+
     Screencasting *const m_screencasting;
     std::unique_ptr<PipeWireRecord> m_recorder;
 };
